==> restx-monitor-admin-1.0.0-sources.jar: restx/monitor/SessionsResourceRouterFactoryMachine.java <==
package restx.monitor;

import com.google.common.collect.ImmutableSet;
import restx.factory.*;
import restx.monitor.SessionsResourceRouter;

@Machine
public class SessionsResourceRouterFactoryMachine extends SingleNameFactoryMachine<restx.monitor.SessionsResourceRouter> {
    public static final Name<restx.monitor.SessionsResourceRouter> NAME = Name.of(restx.monitor.SessionsResourceRouter.class, "SessionsResourceRouter");

    public SessionsResourceRouterFactoryMachine() {
        super(0, new StdMachineEngine<restx.monitor.SessionsResourceRouter>(NAME, 0, BoundlessComponentBox.FACTORY) {
private final Factory.Query<restx.monitor.SessionsResource> resource = Factory.Query.byClass(restx.monitor.SessionsResource.class).mandatory();
private final Factory.Query<restx.entity.EntityRequestBodyReaderRegistry> readerRegistry = Factory.Query.byClass(restx.entity.EntityRequestBodyReaderRegistry.class).mandatory();
private final Factory.Query<restx.entity.EntityResponseWriterRegistry> writerRegistry = Factory.Query.byClass(restx.entity.EntityResponseWriterRegistry.class).mandatory();
private final Factory.Query<restx.converters.MainStringConverter> converter = Factory.Query.byClass(restx.converters.MainStringConverter.class).mandatory();
private final Factory.Query<restx.security.PermissionFactory> pf = Factory.Query.byClass(restx.security.PermissionFactory.class).mandatory();
private final Factory.Query<javax.validation.Validator> validator = Factory.Query.byClass(javax.validation.Validator.class).optional();
private final Factory.Query<restx.security.RestxSecurityManager> securityManager = Factory.Query.byClass(restx.security.RestxSecurityManager.class).mandatory();
private final Factory.Query<restx.endpoint.EndpointParameterMapperRegistry> paramMapperRegistry = Factory.Query.byClass(restx.endpoint.EndpointParameterMapperRegistry.class).mandatory();

            @Override
            public BillOfMaterials getBillOfMaterial() {
                return new BillOfMaterials(ImmutableSet.<Factory.Query<?>>of(
resource,
readerRegistry,
writerRegistry,
converter,
pf,
validator,
securityManager,
paramMapperRegistry
                ));
            }

            @Override
            protected restx.monitor.SessionsResourceRouter doNewComponent(SatisfiedBOM satisfiedBOM) {
                return new SessionsResourceRouter(
satisfiedBOM.getOne(resource).get().getComponent(),
satisfiedBOM.getOne(readerRegistry).get().getComponent(),
satisfiedBOM.getOne(writerRegistry).get().getComponent(),
satisfiedBOM.getOne(converter).get().getComponent(),
satisfiedBOM.getOne(pf).get().getComponent(),
satisfiedBOM.getOneAsComponent(validator),
satisfiedBOM.getOne(securityManager).get().getComponent(),
satisfiedBOM.getOne(paramMapperRegistry).get().getComponent()
                );
            }
        });
    }

}

==> restx-monitor-admin-1.1.0-sources.jar: restx/monitor/SessionsResourceRouterFactoryMachine.java <==
package restx.monitor;

import com.google.common.collect.ImmutableSet;
import restx.factory.*;
import restx.monitor.SessionsResourceRouter;

@Machine
public class SessionsResourceRouterFactoryMachine extends SingleNameFactoryMachine<restx.monitor.SessionsResourceRouter> {
    public static final Name<restx.monitor.SessionsResourceRouter> NAME = Name.of(restx.monitor.SessionsResourceRouter.class, "SessionsResourceRouter");

    public SessionsResourceRouterFactoryMachine() {
        super(0, new StdMachineEngine<restx.monitor.SessionsResourceRouter>(NAME, 0, BoundlessComponentBox.FACTORY) {
private final Factory.Query<restx.monitor.SessionsResource> resource = Factory.Query.byClass(restx.monitor.SessionsResource.class).mandatory();
private final Factory.Query<restx.entity.EntityRequestBodyReaderRegistry> readerRegistry = Factory.Query.byClass(restx.entity.EntityRequestBodyReaderRegistry.class).mandatory();
private final Factory.Query<restx.entity.EntityResponseWriterRegistry> writerRegistry = Factory.Query.byClass(restx.entity.EntityResponseWriterRegistry.class).mandatory();
private final Factory.Query<restx.converters.MainStringConverter> converter = Factory.Query.byClass(restx.converters.MainStringConverter.class).mandatory();
private final Factory.Query<restx.security.PermissionFactory> pf = Factory.Query.byClass(restx.security.PermissionFactory.class).mandatory();
private final Factory.Query<jakarta.validation.Validator> validator = Factory.Query.byClass(jakarta.validation.Validator.class).optional();
private final Factory.Query<restx.security.RestxSecurityManager> securityManager = Factory.Query.byClass(restx.security.RestxSecurityManager.class).mandatory();
private final Factory.Query<restx.endpoint.EndpointParameterMapperRegistry> paramMapperRegistry = Factory.Query.byClass(restx.endpoint.EndpointParameterMapperRegistry.class).mandatory();

            @Override
            public BillOfMaterials getBillOfMaterial() {
                return new BillOfMaterials(ImmutableSet.<Factory.Query<?>>of(
resource,
readerRegistry,
writerRegistry,
converter,
pf,
validator,
securityManager,
paramMapperRegistry
                ));
            }

            @Override
            protected restx.monitor.SessionsResourceRouter doNewComponent(SatisfiedBOM satisfiedBOM) {
                return new SessionsResourceRouter(
satisfiedBOM.getOne(resource).get().getComponent(),
satisfiedBOM.getOne(readerRegistry).get().getComponent(),
satisfiedBOM.getOne(writerRegistry).get().getComponent(),
satisfiedBOM.getOne(converter).get().getComponent(),
satisfiedBOM.getOne(pf).get().getComponent(),
satisfiedBOM.getOneAsComponent(validator),
satisfiedBOM.getOne(securityManager).get().getComponent(),
satisfiedBOM.getOne(paramMapperRegistry).get().getComponent()
                );
            }
        });
    }

}
